@@ -36,7 +36,7 @@ class ListSizeBetween(MetaHandlerGenerator):
             nctx = ctx.copy()
             nident = ident + "_" + str(i)
             nctx["_"] = nident
-            new_symbol(base_type, fin, depth - 1, nident, nctx)
+            new_symbol(base_type, fin, depth, nident, nctx)
 
     def mutate(
         self,
@@ -48,7 +48,7 @@ class ListSizeBetween(MetaHandlerGenerator):
         method,
         current_node,
     ):
-        mutation_method = r.randint(0, 2)
+        mutation_method = r.randint(0, 1)
         if (mutation_method == 0) and (len(current_node) != self.min):  # del
             element_to_be_deleted = r.randint(0, len(current_node) - 1)
             current_node.remove(current_node[element_to_be_deleted])
@@ -130,7 +130,7 @@ class ListSizeBetweenWithoutListOperations(MetaHandlerGenerator):
             nctx = ctx.copy()
             nident = ident + "_" + str(i)
             nctx["_"] = nident
-            new_symbol(base_type, fin, depth - 1, nident, nctx)
+            new_symbol(base_type, fin, depth, nident, nctx)
 
     def __class_getitem__(self, args):
         return ListSizeBetweenWithoutListOperations(*args)
