@@ -1,15 +1,18 @@
+from __future__ import annotations
+
+from geneticengine.algorithms.gp.gp import GP  # noqa
+from geneticengine.core.decorators import abstract  # noqa
 from geneticengine.core.grammar import extract_grammar  # noqa
-from geneticengine.core.representations.tree.treebased import (
-    treebased_representation,
-    random_node,
-)  # noqa
-from geneticengine.core.representations.grammatical_evolution import (
+from geneticengine.core.random.sources import RandomSource  # noqa
+from geneticengine.core.representations.grammatical_evolution.ge import (
     ge_representation,
 )  # noqa
-from geneticengine.core.decorators import abstract  # noqa
-from geneticengine.core.random.sources import RandomSource  # noqa
-from geneticengine.algorithms.gp.gp import GP  # noqa
+from geneticengine.core.representations.grammatical_evolution.structured_ge import (
+    sge_representation,
+)  # noqa
+from geneticengine.core.representations.tree.treebased import random_node
+from geneticengine.core.representations.tree.treebased import treebased_representation
+from geneticengine.metahandlers.floats import FloatRange  # noqa
+from geneticengine.metahandlers.ints import IntRange  # noqa
 from geneticengine.metahandlers.lists import ListSizeBetween  # noqa
 from geneticengine.metahandlers.vars import VarRange  # noqa
-from geneticengine.metahandlers.ints import IntRange  # noqa
-from geneticengine.metahandlers.floats import FloatRange  # noqa
